'use client';
import { jsx as _jsx } from "react/jsx-runtime";
import { use, useRef } from 'react';
import { initializeDevCycle } from '@devcycle/js-client-sdk';
import { invalidateConfig } from '../../common/invalidateConfig';
import { DevCycleProviderContext } from './context';
import { useRouter } from 'next/navigation';
const isServer = typeof window === 'undefined';
export const InternalDevCycleClientsideProvider = ({ context, children, promiseResolved, }) => {
    const clientRef = useRef();
    const router = useRouter();
    const { serverDataPromise, serverData, clientSDKKey, enableStreaming } = context;
    const revalidateConfig = async (lastModified) => {
        var _a;
        if (context.realtimeDelay) {
            // wait configured delay before checking for new config
            await new Promise((resolve) => setTimeout(resolve, context.realtimeDelay));
        }
        try {
            await invalidateConfig(clientSDKKey, (_a = serverData === null || serverData === void 0 ? void 0 : serverData.user.user_id) !== null && _a !== void 0 ? _a : null);
        }
        catch {
            // do nothing on failure, this is best effort
        }
        if (context.realtimeDelay) {
            // if delay is configured, assume that the server action invalidation won't update any content and just
            // call for a full in-place refresh
            router.refresh();
        }
    };
    let resolvedServerData = serverData;
    if (!serverData && promiseResolved) {
        // here the provider is being told from above that this promise has already resolved, so we can safely "use"
        // it without blocking rendering, even in streaming mode
        resolvedServerData = use(serverDataPromise);
    }
    if (!clientRef.current) {
        clientRef.current = initializeDevCycle(clientSDKKey, {
            ...context.options,
            sdkPlatform: 'nextjs',
            deferInitialization: true,
            disableConfigCache: true,
            ...(isServer
                ? {
                    disableAutomaticEventLogging: true,
                    disableCustomEventLogging: true,
                }
                : {}),
            next: {
                configRefreshHandler: revalidateConfig,
            },
        });
        if (resolvedServerData || !enableStreaming) {
            // we expect that either the promise has resolved and we got the server data that way, or we weren't in
            // streaming mode and so the promise was awaited at a higher level and passed in here as serverData
            if (!resolvedServerData) {
                throw new Error('Server data should be available. Please contact DevCycle support.');
            }
            clientRef.current.synchronizeBootstrapData(resolvedServerData.config, resolvedServerData.user, resolvedServerData.userAgent);
        }
        else {
            // if the promise isnt resolved yet, schedule it to synchronize when it is
            // we check the above condition first to make sure we can use the resolved data on the first render pass
            // since the `.then` here is only evaluated after this render pass is finished
            serverDataPromise.then((serverData) => {
                clientRef.current.synchronizeBootstrapData(serverData.config, serverData.user, serverData.userAgent);
            });
        }
    }
    return (_jsx(DevCycleProviderContext.Provider, { value: {
            client: clientRef.current,
            clientSDKKey,
            enableStreaming,
            serverDataPromise,
        }, children: children }));
};
//# sourceMappingURL=InternalDevCycleClientsideProvider.js.map